@@ -2,7 +2,7 @@
 from plot_map import plot_map,plotscale
 from .grids import *
 from .grids_geohash import geohash_encode,geohash_decode,geohash_togrid
-from .ckdnearest import *
+from .gisprocess import *
 from .odprocess import *
 from .preprocess import *
 from .bikedata import *
@@ -11,4 +11,4 @@ from .traj import *
 from .quality import *
 from .busgps import *
 from .getbusdata import *
-__version__ = '0.1.17'
\ No newline at end of file
+__version__ = '0.1.18'
\ No newline at end of file
